Changelog
=================================================

1.0.1 (11/23/2025)
-------------------
* fix bug in calculation of t_s
* add tests for fresnel calculations
* fix __version__ so github actions work correctly

1.0.0 (11/23/2025)
-------------------
* support for jupyterlite
* use pyproject.toml and requirements-dev.txt
* better citation
* normalizing code formatting with black
* use venv for development consistency

0.9.3 (9/18/2023)
-----------------
* fixing zenodo

0.9.2 (9/18/2023)
-----------------
* automatic updating of pypi using github workflow

0.9.1 (9/18/2023)
-----------------
* include test files in tarball

0.9.0 (9/18/2023)
-----------------
* add citation with zenodo DOI
* add copyright to docs
* add conda support
* improve badges
* add automated github testing
* remove deprecated np.complex
* fix doc build
* add github auto testing
* lint files
* update refractive index urls in notebooks

v0.8.2 (9/5/2021)
-----------------
* do not import gaertner.py so pyserial is not a dependency

v0.8.1 (9/5/2021)
-----------------
* create pure python packages
* include wheel file
* package as python3 only
* allow degrees to be used
* add pypi badge
* remove unneeded shell commands
* remove unneeded pyserial dependency

v0.8.0
------
* documentation improvements
* automated notebook testing
* use sympy.I and sympy.pi

v0.7.0
------
* add Poincaré sphere support
* allow lists of Jones/Stokes vector to be processed
* add some basic tox tests

v0.6.0
------
* use sphinx for documentation
* host docs on https://pypolar.readthedocs.io
* remove unneeded files from pip installation
* start using tox for testing

v0.5.1
------
* fix jones.intensity() and sym_jones.intensity()

v0.5.0
------
* add symbolic routines
* add more mueller functions
* rename some stuff
* modify names for polarization ellipse
* improve readme
* split visualization into separate document

v0.3.1
------
* hopefully fix packaging
* fix phase for TIR of dielectrics

v0.3.0
------
* add basic routines for Mueller and Stokes vectors
* rename a bunch of routines
* repackage with the intent that modules will be used separately
* add Jupyter notebooks to provide basic documentation
* add basic ellipsometry support

v0.2.0
------
* add Fresnel transmission
* handle total internal reflection better

v0.1.1
------
* fix packaging error

v0.1.0
------
* initial checkin
